CreateRecord

Struct CreateRecord 

pub struct CreateRecord {
    pub insert_query: DbQuery,
    pub select_defaults: Option<CreateRecordDefaultsQuery>,
    pub last_insert_id_field: Option<ScalarField>,
    pub merge_values: Vec<(SelectedField, PrismaValue)>,
}
An insertion operation for a record in the database.

Fields

insert_query: DbQuery

The insert query to run in order to create the record.

select_defaults: Option<CreateRecordDefaultsQuery>

The query to run prior to the insert in order to create default column values. This is used in some cases where the database does not support returning default values.

last_insert_id_field: Option<ScalarField>

The field in the model of the record that corresponds to the last inserted ID, if required by the database.

merge_values: Vec<(SelectedField, PrismaValue)>

The values to merge into the resulting record after insertion. These are inferred from the input arguments.