pub struct CreateRecordDefaultsQuery {
pub query: DbQuery,
pub field_placeholders: Vec<(ScalarField, Placeholder)>,
}Expand description
A query that retrieves default values needed for an insert operation.
Fields
query: DbQueryThe query that returns the default values.
field_placeholders: Vec<(ScalarField, Placeholder)>The fields that are selected in the query and their corresponding placeholders. These placeholders are referred to by the subsequent insert query.