QueryArgumentsExt

Trait QueryArgumentsExt 

pub trait QueryArgumentsExt {
    // Required method
    fn needs_reversed_order(&self) -> bool;
}

Required Methods

fn needs_reversed_order(&self) -> bool

If we need to take rows before a cursor position, then we need to reverse the order in SQL.

Implementations on Foreign Types

Source

impl QueryArgumentsExt for QueryArguments

Implementors